@@ -85,8 +85,8 @@ function(x,
     stop(sQuote("cmin"), " must be greater than 0!", call. = FALSE)
   }
 
-  if (cmin > cmax) {
-    stop(sQuote("cmin"), " must be less or equal than ", cmax, "!", call. = FALSE)
+  if (cmin >= cmax) {
+    stop(sQuote("cmax"), " must be greater than ", cmin, "!", call. = FALSE)
   }  
 
   bsampleest <- REBMIX(Dataset = Dataset,
@@ -264,8 +264,8 @@ function(x,
     stop(sQuote("cmin"), " must be greater than 0!", call. = FALSE)
   }
 
-  if (cmin > cmax) {
-    stop(sQuote("cmin"), " must be less or equal than ", cmax, "!", call. = FALSE)
+  if (cmin >= cmax) {
+    stop(sQuote("cmax"), " must be greater than ", cmin, "!", call. = FALSE)
   }  
 
   bsampleest <- REBMIX(model = "REBMVNORM",
