@@ -6,6 +6,7 @@ setMethod("a.acceleration", signature(x = "EM.Control"), function(x) x@accelerat
 setMethod("a.tolerance", signature(x = "EM.Control"), function(x) x@tolerance)
 setMethod("a.acceleration.multiplier", signature(x = "EM.Control"), function(x) x@acceleration.multiplier)
 setMethod("a.maximum.iterations", signature(x = "EM.Control"), function(x) x@maximum.iterations)
+setMethod("a.K", signature(x = "EM.Control"), function(x) x@K)
 
 setMethod("a.strategy<-",
           signature = (x = "EM.Control"),
@@ -151,6 +152,33 @@ function(x, value)
   x
 }) ## a.maximum.iterations<-
 
+setMethod("a.K<-",
+          signature = (x = "EM.Control"),
+function(x, value)
+{
+  # value.
+  
+  if (missing(value) || (length(value) == 0)) {
+    stop(sQuote("K"), " must not be empty!", call. = FALSE)
+  }
+
+  if (!is.wholenumber(value)) {
+    stop(sQuote("K"), " integer is requested!", call. = FALSE)
+  }
+
+  length(value) <- 1
+
+  if (value < 0) {
+    stop(sQuote("K"), " must be greater or equal than 0!", call. = FALSE)
+  }  
+
+  x@K <- value
+
+  rm(list = ls()[!(ls() %in% c("x"))])
+
+  x
+}) ## a.K<-
+
 ### End
 
 setMethod("a.c", signature(x = "RNGMIX.Theta"), function(x) x@c)
