@@ -9,24 +9,19 @@
 #ifndef EMF_H_INCLUDED
 #define EMF_H_INCLUDED
 
-#ifdef _MSC_VER
-#pragma warning(disable: 4514)
-#pragma warning(disable: 4820)
-#endif
-
-#include <stdlib.h>
-#include <string.h>
 #include "base.h"
 
 class Emmix : public Base {
 public:
     // Members.
     int                  n_;               // Number of observations.
+	int                  k_;               // Total number of bins.
     FLOAT                **Y_;             // Dataset.
     int                  cmax_;            // Maximum number of components.
     FLOAT                TOL_;             // Tolerance for EM algorithm.
     FLOAT                am_;              // Acceleration multiplier for EM algorithm.
     int                  max_iter_;        // Maximum number of iterations of EM algorithm.
+	int                  K_;               // Number of bins for histogram EM algorithm.
     EmStrategyType_e     strategy_;        // EM strategy utilization.
     EmVariantType_e      variant_;         // Type of EM variant algorithm.
     EmAccelerationType_e accel_;           // Type of acceleration of standard EM algorithm.
@@ -42,7 +37,8 @@ public:
     Emmix();
     // Destructor.
     virtual ~Emmix();
-    int Initialize(int n, FLOAT **Y, int cmax, int length_pdf, int length_Theta, int *length_theta, FLOAT TOL, FLOAT am, int max_iter, EmStrategyType_e strategy, EmVariantType_e variant, EmAccelerationType_e accel);
+    int Initialize(int n, FLOAT **Y, int cmax, int length_pdf, int length_Theta, int *length_theta, FLOAT TOL, FLOAT am, int max_iter, int EM_K, EmStrategyType_e strategy, EmVariantType_e variant, EmAccelerationType_e accel);
+	int Transform(FLOAT **Y);
     int MixtureDist(int j, FLOAT **Y, int c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *MixDist);
     int LogLikelihood(int c, FLOAT *W, CompnentDistribution **MixTheta, FLOAT *LogL);
     int ExpectationStep();
