@@ -1,9 +1,6 @@
 #ifndef RNGMVNORM_H_INCLUDED
 #define RNGMVNORM_H_INCLUDED
 
-#include <stdlib.h>
-#include <string.h>
-
 #include "base.h"
 #include "rngmixf.h"
 
